Instructions to run the unittest:

1. Run `pytest` for running all unit tests
2. Run `pytest --mode=save_threshold --plot` for running all unittest, save the threshold, and plotting the results.
3. For running only 1 unittest: `pytest test/test_model_forecast.py --mode=save_threshold --plot`